/*
 Author    : Loe Feijs
 Date      : 20130302
 
 This example shows how to control a LED using a finite state 
 machine. The LED goes on when the button switch is pushed. 
 The LED goes off after 10 seconds.
 
 Author    : P.Peters
 Date      : 20131202
 
 Modified code such that it fits my test plug
 pin 9 is used as GND, and connects to the LED and button.
 pin 10 has a 470 Ohm resistor to the LED
 pin 11 has a 470 Ohm resistor to the other side of the button
 In order to operate, pin 9 must be 0, and pin 11 must have pullup
 
 */

//connect LED, Button:
#define gndPin 9
#define ledPin 10
#define buttonPin 11

//FSM states:
#define OFF 0
#define ON  1
#define timerDelay 400

// initialisation
int state = OFF;
int timer = 0;
boolean event = false;


void setup()  { 
  pinMode(gndPin,OUTPUT);
  digitalWrite(gndPin,0);
  pinMode(ledPin, OUTPUT); 
  pinMode(buttonPin, INPUT_PULLUP);
} 

void loop()  { 
  LEDstep();
  delay(10); // one step every 10 ms
}

/*
Finite state machine implementation
 */
void LEDstep(){

  switch (state){
  case OFF:
    if (digitalRead(buttonPin) == LOW){
      // change state
      state = ON;
      // state transition actions
      timer = timerDelay; // 10 millisecond steps 
      analogWrite(ledPin,255); // max brightness
    }  
    break;
  case ON: 
    if (timer <= 0){
      // change state
      state = OFF;
      // state transition actions
      analogWrite(ledPin,0);
    } 
    else timer--;
    break;
  }
}





